pub struct CreateCmd {
pub para_id: Option<u32>,
pub relay_chain: Option<String>,
pub properties: Vec<String>,
/* private fields */
}Expand description
Create a new chain spec by interacting with the provided runtime wasm blob.
Fields
para_id: Option<u32>The para ID for your chain.
relay_chain: Option<String>The relay chain you wish to connect to.
properties: Vec<String>Chain properties in KEY=VALUE format.
Multiple KEY=VALUE entries can be specified and separated by a comma.
Example: --properties tokenSymbol=UNIT,tokenDecimals=12,ss58Format=42,isEthereum=false
Or: --properties tokenSymbol=UNIT --properties tokenDecimals=12 --properties ss58Format=42 --properties=isEthereum=false
The first uses comma as separation and the second passes the argument multiple times. Both styles can also be mixed.